/* 
 * SCIE -- Spinal Cord Injury Ontology Extraction
 * Copyright (C) 2013, 2014
 * Raphael Dickfelder, Jan Göpfert, Benjamin Paaßen, Andreas Stöckel
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.techfak.scie.pdfextractor;

import de.unibi.techfak.scie.pdfextractor.structure.Document;
import de.unibi.techfak.scie.pdfextractor.structure.Page;
import de.unibi.techfak.scie.pdfextractor.structure.Paragraph;
import de.unibi.techfak.scie.pdfextractor.structure.Text;
import de.unibi.techfak.scie.pdfextractor.structure.TextBlock;
import java.util.Random;
import static junit.framework.Assert.assertEquals;
import static junit.framework.Assert.assertEquals;
import static junit.framework.Assert.assertEquals;
import static junit.framework.Assert.assertEquals;
import static junit.framework.Assert.assertEquals;
import static junit.framework.Assert.assertFalse;
import static junit.framework.Assert.assertFalse;
import static junit.framework.Assert.assertFalse;
import static junit.framework.Assert.assertFalse;
import static junit.framework.Assert.assertFalse;
import static junit.framework.Assert.assertTrue;
import static junit.framework.Assert.assertTrue;
import static junit.framework.Assert.assertTrue;
import static junit.framework.Assert.assertTrue;
import static junit.framework.Assert.assertTrue;
import junit.framework.TestCase;

/**
 *
 * @author Benjamin Paassen - bpaassen@techfak.uni-bielefeld.de
 */
public class DocumentBlockCleanerTest extends TestCase {
	
	public DocumentBlockCleanerTest(String testName) {
		super(testName);
	}
	
	@Override
	protected void setUp() throws Exception {
		super.setUp();
	}
	
	@Override
	protected void tearDown() throws Exception {
		super.tearDown();
	}

	/**
	 * Test of blockCleanup method, of class DocumentBlockCleaner.
	 */
	public void testBlockCleanup() {
		//set up an artificial document with page numbers that can be cleaned.
		final Document doc = new Document();
		final int pages = 10;
		final int blockNum = 4;
		final int blockLength = 150;
		final Random rand = new Random();
		for (int i = 0; i < pages; i++) {
			final Page page = new Page();
			doc.content.add(page);
			//fill each page with some blocks that contain random text.
			for (int j = 0; j < blockNum; j++) {
				final StringBuilder blockBuilder = new StringBuilder();
				for (int k = 0; k < blockLength; k++) {
					int charnum = rand.nextInt(26);
					char c = (char) (charnum + 97);
					blockBuilder.append(c);
				}
				final TextBlock block = new TextBlock();
				page.content.add(block);
				final Paragraph par = new Paragraph();
				block.content.add(par);
				final Text text = new Text();
				text.setText(blockBuilder.toString());
				par.content.add(text);
			}
			//and add a last block only containing the page number.
			final TextBlock pageNumBlock = new TextBlock();
			page.content.add(pageNumBlock);
			final Paragraph pageNumPar = new Paragraph();
			pageNumBlock.content.add(pageNumPar);
			final Text pageNumText = new Text();
			pageNumText.setText("This is the page numbered " + Integer.toString(i + 1));
			pageNumPar.content.add(pageNumText);
		}
		//check if the page numbers are contained.
		String xml = doc.toXML();
		for (int p = 1; p <= pages; p++) {
			assertTrue(xml.contains("This is the page numbered " + p));
		}

		//now clean the document.
		final DocumentBlockCleaner instance = new DocumentBlockCleaner();
		instance.blockCleanup(doc);
		xml = doc.toXML();
		for (int p = 1; p <= pages; p++) {
			//and now we do not expect the page numbers to be there anymore.
			assertFalse(xml.contains("This is the page numbered " + p));
			//other than that it should still be complete.
			assertEquals(blockNum, doc.content.get(p - 1).content.size());
		}
	}
}
