/* 
 * SCIE -- Spinal Cord Injury Ontology Extraction
 * Copyright (C) 2013, 2014
 * Raphael Dickfelder, Jan Göpfert, Benjamin Paaßen, Andreas Stöckel
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.techfak.scie.pdfextractor;

import junit.framework.TestCase;

/**
 *
 * @author Benjamin Paassen - bpaassen(at)techfak.uni-bielefeld.de
 */
public class StringSimilarityTest extends TestCase {

	public StringSimilarityTest(String testName) {
		super(testName);
	}

	@Override
	protected void setUp() throws Exception {
		super.setUp();
	}

	@Override
	protected void tearDown() throws Exception {
		super.tearDown();
	}

	/**
	 * Test of calculate method, of class StringSimilarity.
	 */
	public void testCalculate() {
		final StringSimilarity instance = new StringSimilarity();

		//equal strings should be totally similar.
		assertEquals(1, instance.calculate("testString", "testString"), 0.0);
		//numbers should not mess with that
		assertEquals(1, instance.calculate("testString1", "testString2"), 0.0);
		//for absolutely unequal strings we expect a value of 0.
		assertEquals(0, instance.calculate("abcd", "gh"), 0.0);
		assertEquals(0, instance.calculate("gh", "abcd"), 0.0);
		/* 
		 * for any other other string combination, that bears some similarity, we expect some 
		 * intermediate value.
		 * to be more precise we expect 1 - the edit distance divided by the worst case edit distance
		 */
		assertEquals(0.25, instance.calculate("abcd", "a"));
		assertEquals(0.25, instance.calculate("a", "abcd"));
		assertEquals(0.5, instance.calculate("abcd", "ab"));
		assertEquals(0.5, instance.calculate("ab", "abcd"));
		assertEquals(0.75, instance.calculate("abcd", "abc"));
		assertEquals(0.75, instance.calculate("abc", "abcd"));
	}
}
